LearningConfigBuilder

Struct LearningConfigBuilder 

pub struct LearningConfigBuilder { /* private fields */ }
Fluent builder for LearningConfig.

Implementations

Source

impl LearningConfigBuilder

pub fn alpha(self, v: f64) -> Self

Sets the TD learning rate α.

pub fn gamma(self, v: f64) -> Self

Sets the discount factor γ.

pub fn epsilon(self, v: f64) -> Self

Sets the initial exploration probability ε.

pub fn epsilon_decay(self, v: f64) -> Self

Sets the per-episode ε decay multiplier.

pub fn epsilon_min(self, v: f64) -> Self

Sets the minimum ε floor.

pub fn distill_top_k(self, k: usize) -> Self

Sets how many cold entries are promoted per distillation pass.

pub fn distill_threshold(self, v: f64) -> Self

Sets the distillation reward threshold.

pub fn elastic_lambda(self, v: f64) -> Self

Sets the elastic penalty λ.

pub fn elastic_pin_count(self, n: usize) -> Self

Sets the activation count threshold for pinning.

pub fn federated_blend(self, v: f64) -> Self

Sets the federated blend weight.

pub fn meta_top_k(self, k: usize) -> Self

Sets the number of meta-prototypes considered per lookup.

pub fn pmi_min_count(self, n: usize) -> Self

Sets the minimum PMI co-occurrence count.

pub fn active_modes(self, modes: HashSet<LearningMode>) -> Self

Sets the enabled learning modes.

pub fn build(self) -> LearningConfig

Builds the LearningConfig by applying all overrides on top of defaults.